@@ -4,6 +4,7 @@ import gzip
 import filesystem_query
 import experiment_years
 import esgf_query
+import copy
 
 def union_headers(diag_headers):
     #Create the diagnostic description dictionary:
@@ -158,15 +159,10 @@ def simulations(simulations_desc):
         infile=open(simulations_desc.in_diagnostic_pointers_file,'r')
     paths_dict=json.load(infile)
 
-    for center in paths_dict['data_pointers'].keys():
-        if center[0]!='_':
-            for model in paths_dict['data_pointers'][center].keys():
-                if model[0]!='_':
-                    for rip in paths_dict['data_pointers'][center][model].keys():
-                        if rip[0]!='_':
-                            print center+','+model+','+rip
+    print paths_dict['simulations_list']
     return
 
+
 def main():
     import sys
     import argparse 
