@@ -101,7 +101,7 @@ def experiment_variable_search(session,file_expt,search_path,file_type_list,expe
                 file_description=item.json['title'].split('.aggregation')[0].split('.')
                 variable=file_description[-2]
                 if variable==var_name:
-                    print file_description
+                    #print file_description
                     url_name=item.opendap_url
                     if url_name!=None:
                         file_expt_copy = copy.deepcopy(file_expt)
